@@ -166,7 +166,7 @@ async def _append_line(filename, line):
 
 async def watch(stream, prefix=''):
     async for line in stream:
-        log.info(prefix + line.decode().strip())
+        print(line.decode().strip())
 
 @asyncio.coroutine
 def inplace_change(filename, old_string, new_string):
@@ -211,7 +211,7 @@ class TaskDefs(dict):
             if 'dir' in obj:
                 post = obj['dir']
                 directory = directory + '/' + post.replace('$', '')
-                self.run_vars['dir'] =  directory  
+            self.run_vars['dir'] =  directory  
 
             if 'condition' in obj:
                 self.run_vars['condition'] = obj['condition'].replace('$', '')
@@ -370,8 +370,6 @@ class SequentialTaskList(TaskList):
         env = os.environ.copy()
         self.vars.update(env)
 
-#        os.chdir(self.vars['dir'])
-
         if self.condition == False:
             condition = await env_ject(self.vars['condition'])
             if eval(condition , self.vars):
